Module Constants
================

.. currentmodule:: plutoprint

.. autodata:: __version__

.. autodata:: __version_info__

.. autodata:: __build_info__

.. autodata:: PLUTOBOOK_VERSION

.. autodata:: PLUTOBOOK_VERSION_MAJOR

.. autodata:: PLUTOBOOK_VERSION_MICRO

.. autodata:: PLUTOBOOK_VERSION_MINOR

.. autodata:: PLUTOBOOK_VERSION_STRING

Module Functions
================

.. autofunction:: plutobook_version

.. autofunction:: plutobook_version_string

.. autofunction:: plutobook_build_info

.. autofunction:: plutobook_set_fontconfig_path
